========
Pipeline
========

.. module:: phenotastic.pipeline

The pipeline module provides classes for configuring and executing
reproducible processing workflows.

Pipeline Class
--------------

.. autoclass:: phenotastic.Pipeline
   :members:
   :undoc-members:
   :show-inheritance:

PipelineContext Class
---------------------

.. autoclass:: phenotastic.PipelineContext
   :members:
   :undoc-members:
   :show-inheritance:

StepConfig Class
----------------

.. autoclass:: phenotastic.StepConfig
   :members:
   :undoc-members:
   :show-inheritance:

OperationRegistry Class
-----------------------

.. autoclass:: phenotastic.OperationRegistry
   :members:
   :undoc-members:
   :show-inheritance:

Preset Functions
----------------

.. autofunction:: phenotastic.load_preset

.. autofunction:: phenotastic.list_presets

.. autofunction:: phenotastic.get_preset_yaml

.. autofunction:: phenotastic.save_pipeline_yaml
